## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

library(datazoom.social)


## ----eval=FALSE---------------------------------------------------------------
# panel_data <- build_pnadc_panel(dat = pnad_sample, panel = "basic")
# 

## ----eval=FALSE---------------------------------------------------------------
# # Stage 1: Exact matching with donated birth dates
# panel_data <- build_pnadc_panel(dat = pnad_sample, panel = "advanced_1")
# 
# # Stage 2: Relaxed matching constraints
# panel_data <- build_pnadc_panel(dat = pnad_sample, panel = "advanced_2")
# 
# # Stage 3: Fuzzy matching using Graph Theory (Recommended)
# panel_data <- build_pnadc_panel(dat = pnad_sample, panel = "advanced_3")
# 

